@@ -1,16 +1,24 @@
-#' Get object from the `qenv` environment
+#' Get object from `qenv`
+#'
+#' Retrieve variables from the `qenv` environment.
+#'
+#' @param object,x (`qenv`)
+#' @param var,i (`character(1)`) variable name.
 #'
-#' Get object from the `qenv` environment.
-#' @param object (`qenv`)
-#' @param var (`character(1)`) name of the variable to pull from the environment.
-#' @name get_var
 #' @return The value of required variable (`var`) within `qenv` object.
+#'
 #' @examples
-#' q1 <- new_qenv(env = list2env(list(a = 1)), code = quote(a <- 1))
+#' q <- qenv()
+#' q1 <- eval_code(q, code = quote(a <- 1))
 #' q2 <- eval_code(q1, code = "b <- a")
 #' get_var(q2, "b")
 #' q2[["b"]]
 #'
+#' @name get_var
+#' @rdname get_var
+#' @aliases get_var,qenv,character-method
+#' @aliases get_var,qenv.error,ANY-method
+#'
 #' @export
 setGeneric("get_var", function(object, var) {
   grDevices::pdf(nullfile())
@@ -18,12 +26,9 @@ setGeneric("get_var", function(object, var) {
   standardGeneric("get_var")
 })
 
-
-#' @rdname get_var
-#' @export
 setMethod("get_var", signature = c("qenv", "character"), function(object, var) {
   tryCatch(
-    get(var, envir = object@env),
+    get(var, envir = object@env, inherits = FALSE),
     error = function(e) {
       message(conditionMessage(e))
       NULL
@@ -31,29 +36,20 @@ setMethod("get_var", signature = c("qenv", "character"), function(object, var) {
   )
 })
 
-#' @rdname get_var
-#' @export
-setMethod("get_var", signature = "qenv.error", function(object, var) {
+setMethod("get_var", signature = c("qenv.error", "ANY"), function(object, var) {
   stop(errorCondition(
     list(message = conditionMessage(object)),
     class = c("validation", "try-error", "simpleError")
   ))
 })
 
-
-#' @param x (`qenv`)
-#' @param i (`character`) name of the binding in environment (name of the variable)
-#' @param j not used
-#' @param ... not used
 #' @rdname get_var
-#' @export
-setMethod("[[", signature = c("qenv", "ANY", "missing"), function(x, i, j, ...) {
+setMethod("[[", signature = c("qenv", "ANY"), function(x, i) {
   get_var(x, i)
 })
 
-#' @rdname get_var
 #' @export
-`[[.qenv.error` <- function(x, i, j, ...) {
+`[[.qenv.error` <- function(x, i) {
   stop(errorCondition(
     list(message = conditionMessage(x)),
     class = c("validation", "try-error", "simpleError")
