@@ -1,11 +1,13 @@
 testthat::test_that("get_code returns code (character by default) of qenv object", {
-  q <- new_qenv(list2env(list(x = 1)), code = quote(x <- 1))
-  q <- eval_code(q, quote(y <- x))
-  testthat::expect_equal(get_code(q), c("x <- 1", "y <- x"))
+  q <- qenv() |>
+    eval_code(quote(x <- 1)) |>
+    eval_code(quote(y <- x))
+  testthat::expect_equal(get_code(q), paste(c("x <- 1", "y <- x"), collapse = "\n"))
 })
 
 testthat::test_that("get_code returns code elements being code-blocks as character(1)", {
-  q <- new_qenv(list2env(list(x = 1)), code = quote(x <- 1))
+  q <- qenv()
+  q <- eval_code(q, quote(x <- 1))
   q <- eval_code(
     q,
     quote({
@@ -13,17 +15,22 @@ testthat::test_that("get_code returns code elements being code-blocks as charact
       z <- 5
     })
   )
-  testthat::expect_equal(get_code(q), c("x <- 1", "y <- x", "z <- 5"))
+  testthat::expect_equal(get_code(q), paste(c("x <- 1", "y <- x\nz <- 5"), collapse = "\n"))
 })
 
-testthat::test_that("get_code returns code (unparsed) of qenv object if deparse = FALSE", {
-  q <- new_qenv(list2env(list(x = 1)), code = quote(x <- 1))
+testthat::test_that("get_code returns expression of qenv object if deparse = FALSE", {
+  q <- qenv()
+  q <- eval_code(q, quote(x <- 1))
   q <- eval_code(q, quote(y <- x))
-  testthat::expect_equal(get_code(q, deparse = FALSE), q@code)
+  testthat::expect_equivalent(
+    toString(get_code(q, deparse = FALSE)),
+    toString(parse(text = paste(c("{", q@code, "}"), collapse = "\n"), keep.source = TRUE))
+  )
 })
 
 testthat::test_that("get_code called with qenv.error returns error with trace in error message", {
-  q1 <- new_qenv(list2env(list(x = 1)), code = quote(x <- 1))
+  q1 <- qenv()
+  q1 <- eval_code(q1, quote(x <- 1))
   q2 <- eval_code(q1, quote(y <- x))
   q3 <- eval_code(q2, quote(w <- v))
 
