@@ -1,5 +1,5 @@
 testthat::test_that("get_var and `[[`return error if object is qenv.error", {
-  q <- eval_code(new_qenv(), quote(x <- 1))
+  q <- eval_code(qenv(), quote(x <- 1))
   q <- eval_code(q, quote(y <- w * x))
 
   testthat::expect_error(get_var(q, "x"), "when evaluating qenv code")
@@ -7,7 +7,7 @@ testthat::test_that("get_var and `[[`return error if object is qenv.error", {
 })
 
 testthat::test_that("get_var and `[[` return object from qenv environment", {
-  q <- eval_code(new_qenv(), quote(x <- 1))
+  q <- eval_code(qenv(), quote(x <- 1))
   q <- eval_code(q, quote(y <- 5 * x))
 
   testthat::expect_equal(get_var(q, "y"), 5)
@@ -15,7 +15,7 @@ testthat::test_that("get_var and `[[` return object from qenv environment", {
 })
 
 testthat::test_that("get_var and `[[` return NULL if object not in qenv environment", {
-  q <- eval_code(new_qenv(), quote(x <- 1))
+  q <- eval_code(qenv(), quote(x <- 1))
   q <- eval_code(q, quote(y <- 5 * x))
 
   testthat::expect_null(get_var(q, "z"))
@@ -24,3 +24,10 @@ testthat::test_that("get_var and `[[` return NULL if object not in qenv environm
   testthat::expect_null(q[["w"]])
   testthat::expect_message(q[["w"]], "object 'w' not found")
 })
+
+testthat::test_that("get_var and `[[` only returns objects from qenv, not parent environment(s)", {
+  q <- qenv()
+
+  testthat::expect_null(get_var(q, "iris"))
+  testthat::expect_null(q[["iris"]])
+})
